==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-mount/translations/mount_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Cserélhetőeszköz-kezelő</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Cserélhető eszközbeállítás</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Működés</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="26"/>
        <source>When a device is connected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation>Felugró menü</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation>Információ megjelenítése</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation>Ne tegyen semmit</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz csatlakoztatva.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz eltávolítva.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>Cserélhetőeszköz kezelő</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>A &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; felcsatolása sikertelen: %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="157"/>
        <location filename="../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation>Cserélhetőeszköz kezelő</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>A &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; lecsatolása sikertelen: %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>Nincs elérhető eszköz</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-mount/translations/mount_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">Cserélhetőeszköz-kezelő</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation type="unfinished">Cserélhető eszköz beállítások</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Működés</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="26"/>
        <source>When a device is connected:</source>
        <translation type="unfinished">Ha egy eszköz csatlakoztatva van:</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation>Felugró menü</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation>Információ megjelenítése</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation>Ne tegyen semmit</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz csatlakoztatva.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz eltávolítva.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>Cserélhetőeszköz-kezelő</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>A &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; csatolása sikertelen: %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="157"/>
        <location filename="../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation>Cserélhetőeszköz-kezelő</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>A &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; lecsatolása sikertelen: %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>Nincs elérhető eszköz</translation>
    </message>
</context>
</TS>
